/* cap_t.h
 *
 * libcap Wrapper for the Microsoft Network Monitor analyzer
 * By Laurent Rabret <laurent.rabret@francetelecom.com>
 * Copyright 2001 FTR&D
 *
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef ___CAP_T_DECLARE___
#define ___CAP_T_DECLARE___

// size of buffer that stores all frames
#define MAX_SIZE_OF_BUFFER	0xFFFF

class pcap_t_
{
	HBLOB hBlobWorking;
	IRTC* pIRTC;
	char  szError[512];

	DWORD	lostPacket;			// stores number of lost packets in this layer

	const DWORD	 deviceNumber;
	
	const DWORD  ReadTimeOut;	
	const DWORD  MinRange;		// low water mark to read frames
	const DWORD  MaxRange;		// high water mark to read frames

	const DWORD  snaplen;

	lBuffer* pBuffer;
	lBuffer* pBufferLast;
	lBuffer* pRecycler;

	PUCHAR datafield;
	DWORD  fieldbegin;
	DWORD  fieldend;

	CRITICAL_SECTION	m_CS;

public:
	pcap_t_(DWORD dNum, DWORD slen, int promisc, int to_ms, char *ebuf);
	~pcap_t_();
protected:
	BOOL	AddNewFrame(PUCHAR cbuf, unsigned cSize /*off wire*/ , unsigned len /* on wire*/, long time_sec, long time_usec);
	HBLOB	FindAnalyzer(DWORD number);
	BOOL	InitializeLivePCap(int promisc, char *ebuf);

	static DWORD WINAPI FrameProc( UPDATE_EVENT Event );
public:
	// definition of lib PCAP functions
	int		GetFrames(int cnt, pcap_handler callback, u_char *user, BOOL bWithTimeOut);
	int		SetFilter(struct bpf_program *fp);
	int		DataLink();
	int		Stats(struct pcap_stat *ps);

	// these ones are inline
	int		GetSnapShot()		{ return snaplen;}
	int		GetFileNo()			{ return deviceNumber;}
	PCHAR	GetStringError()	{ return szError;}
};

#endif  //___CAP_T_DECLARE___