/* lbuffer.cpp
 *
 * libcap Wrapper for the Microsoft Network Monitor analyzer
 * By Laurent Rabret <laurent.rabret@francetelecom.com>
 * Copyright 2001 FTR&D
 *
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "stdafx.h"

lBuffer::lBuffer(PUCHAR cbuf, unsigned cSize, unsigned len, long time_sec, long time_usec, DWORD fieldBegin, DWORD& fieldEnd, const UCHAR*dataField)
{
	if (cSize > MAX_SIZE_OF_BUFFER) {
		throw -1;
	}

	if ( (fieldEnd + cSize) >= MAX_SIZE_OF_BUFFER) {
		if (!fieldBegin) {
			throw -2;
		}
		fieldEnd = 0;
	}

	if ((fieldEnd >= fieldBegin) || ((fieldEnd + cSize) < fieldBegin)) {
		Buf = (PUCHAR)dataField + fieldEnd;
		fieldEnd += cSize;
	}
	else {
		throw -2;
	}

	memcpy(Buf, cbuf, cSize);
	NextBuf				= fieldEnd;
	pktHead.ts.tv_sec	= time_sec;
	pktHead.ts.tv_usec	= time_usec;
	pktHead.len			= len;
	pktHead.caplen		= cSize;
	next = NULL;
}

lBuffer::~lBuffer()
{
	// don't delete buf !!
	if (next) delete next; 
}


BOOL lBuffer::InitFields(const PUCHAR cbuf, unsigned cSize, unsigned len, long time_sec, long time_usec, DWORD fieldBegin, DWORD& fieldEnd, const UCHAR*dataField)
{
	if (cSize > MAX_SIZE_OF_BUFFER) {
		return FALSE;
	}

	if ( (fieldEnd + cSize) >= MAX_SIZE_OF_BUFFER) {
		if (!fieldBegin) {
			return FALSE;
		}
		fieldEnd = 0;
	}

	if ((fieldEnd >= fieldBegin) || ((fieldEnd + cSize) < fieldBegin)) {
		Buf = (PUCHAR)dataField + fieldEnd;
		fieldEnd += cSize;
	}
	else {
		return FALSE;
	}

	memcpy(Buf, cbuf, cSize);
	NextBuf				= fieldEnd;
	pktHead.ts.tv_sec	= time_sec;
	pktHead.ts.tv_usec	= time_usec;
	pktHead.len			= len;
	pktHead.caplen		= cSize;
	next				= NULL;
	return TRUE;
}
